@@ -30,6 +30,7 @@ except ImportError:
 
 logger = logging.getLogger(__name__)
 OMNI_API_URL = environ.get("OMNI_API_URL", "http://omni-api:80")
+CHANNEL_ID = environ.get("CHANNEL_ID", 3)
 
 class UserMessage:
     """Represents an incoming message.
@@ -170,35 +171,38 @@ class InputChannel:
         max_retries = 3
         retries = 0
 
-        while retries < max_retries:
-            try:
-                with requests.post(
-                    url=f'{OMNI_API_URL}/getOrCreateChannelId',
-                    data={"channelName": channel_name},
-                    timeout=30,
-                ) as res:
-                    resp_status = res.status_code
-                    resp = res.json()
-                    channel_id = resp.get("channelId", None)
-                    if not channel_id and channel_id != 0:
-                        raise Exception(f"Unable to parse channel id from the response. Response: {resp}")
-                    else:
-                        logger.info(f"Channel: {channel_name}, Channel ID: {channel_id}")
-                        break
-            except Exception:
-                retries += 1
-                logger.warning(f"Failed to get channel id. Retrying in {delay}s...", exc_info=True)
-                time.sleep(delay)
+        # TO DO: replace env variable with direct sql retrieval of channel HYDRA handles
+        # DEPRECATED CODE: makes connection to omni-api to retrieve channel ids
+        # while retries < max_retries:
+        #     try:
+        #         with requests.post(
+        #             url=f'{OMNI_API_URL}/getOrCreateChannelId',
+        #             data={"channelName": channel_name},
+        #             timeout=30,
+        #             verify=False
+        #         ) as res:
+        #             resp_status = res.status_code
+        #             resp = res.json()
+        #             channel_id = resp.get("channelId", None)
+        #             if not channel_id and channel_id != 0:
+        #                 raise Exception(f"Unable to parse channel id from the response. Response: {resp}")
+        #             else:
+        #                 logger.info(f"Channel: {channel_name}, Channel ID: {channel_id}")
+        #                 break
+        #     except Exception:
+        #         retries += 1
+        #         logger.warning(f"Failed to get channel id. Retrying in {delay}s...", exc_info=True)
+        #         time.sleep(delay)
 
-        if retries == max_retries:
-            logger.error(f"Failed to get channel id after {max_retries} retries.")
+        # if retries == max_retries:
+        #     logger.error(f"Failed to get channel id after {max_retries} retries.")
 
-        duration = time.perf_counter() - start
-        OUTGOING_REQUEST_LATENCY_SEC.labels(f'{OMNI_API_URL}/getOrCreateChannelId', resp_status, "POST").observe(
-            duration)
-        return channel_id
+        # duration = time.perf_counter() - start
+        # OUTGOING_REQUEST_LATENCY_SEC.labels(f'{OMNI_API_URL}/getOrCreateChannelId', resp_status, "POST").observe(
+        #     duration)
+        return CHANNEL_ID
 
-    async def startTracking(self, usg_msg, csi, channel, sid):
+    async def startTracking(self, usg_msg, slots, channel, sid):
         # make IDP request here and append guid to message
         idp_endpoint = InputChannel._available_endpoints.idp
 
@@ -212,7 +216,7 @@ class InputChannel:
 
         headers = {"Conversation-Id": sid, "Tenant-Id": tenant_id}
         params = {
-            "CSI": csi,
+            "CSI": slots.get("channelUserId"),
             "channel": channel
         }
         msg = usg_msg
@@ -231,8 +235,8 @@ class InputChannel:
 
                     # Reformat the initial string
                     if resp.get('guid'):
-                        resp['channelUserId'] = csi
-                        msg = "/greet" + json.dumps(resp)
+                        slots['guid'] = resp.get('guid')
+                        msg = "/greet" + json.dumps(slots)
                         logger.info(f"[{sid}] - User tracked by IDP with GUID. Message: {msg}")
                     else:
                         logger.warning(f"[{sid}] - Unable to retrieve guid from IDP: {resp}")
