@@ -16,8 +16,7 @@ import re
 import string
 from text2digits import text2digits
 from metrics.constants import APP_NAV
-from webservice_connector.voltage import Voltage
-voltage_client = Voltage()
+
 t2d = text2digits.Text2Digits()
 
 from metrics.constants import ACTION_PREDICT_EXECUTE_TIME
@@ -34,7 +33,10 @@ from rasa.core.constants import (
     USER_INTENT_RESTART,
     UTTER_PREFIX,
     USER_INTENT_BACK,
-    USER_INTENT_OUT_OF_SCOPE
+    USER_INTENT_OUT_OF_SCOPE,
+    CDR_ENDPOINT,
+    CDR_ACCOUNT_ID,
+    CDR_ACCOUNT_TOKEN
 )
 from rasa.core.domain import Domain
 from rasa.core.events import (
@@ -66,11 +68,12 @@ logger = logging.getLogger(__name__)
 
 MAX_NUMBER_OF_PREDICTIONS = int(os.environ.get("MAX_NUMBER_OF_PREDICTIONS", "10"))
 MAX_PARTIALS_PROCESSED = int(os.environ.get("MAX_PARTIALS_PROCESSED", 2))
-FC_ENDPOINT = os.environ.get('FC_ENDPOINT')
-FC_ACCOUNT_ID = os.environ.get('FC_ACCOUNT_ID')
-FC_ACCOUNT_TOKEN = os.environ.get('FC_ACCOUNT_TOKEN')
+
+
 redactor = Redactor()
 
+if CDR_ENDPOINT == None or CDR_ACCOUNT_ID == None or CDR_ACCOUNT_TOKEN == None:
+    logger.warning('CDR credentials do not exist, core is unable to submit App Nav events')
 
 class MessageProcessor:
     def __init__(
@@ -556,7 +559,9 @@ class MessageProcessor:
         if '/greet' not in pci_msg and '/disconnect' not in pci_msg and '/restart' not in pci_msg:
             if len(pci_msg) > 0 and pci_msg[-1] in string.punctuation and (pci_msg[-1] not in ['#', '*']):
                 pci_msg = pci_msg[:-1]
-            pci_msg = pci_msg.replace(',', ' ').replace('for ', 'four ').replace('to ', 'two ').replace('too ', 'two ').replace('won ', 'one ').replace('hate ', 'eight ').replace('ate ', 'eight ')
+            pci_msg = ' ' + pci_msg + ' '
+            pci_msg = pci_msg.replace(',', ' ').replace(' for ', ' four ').replace(' to ', ' two ').replace(' too ', ' two ').replace(' won ', ' one ').replace(' hate ', ' eight ').replace(' ate ', ' eight ')
+            pci_msg = pci_msg[1:-1]
             pci_msg_digits = t2d.convert(pci_msg)
             if len(re.findall("\d{12,}", pci_msg_digits)) > 0:
                 pci_msg_digits = re.sub(r'(?<=\d)+ (?=\d)+', '', pci_msg_digits)
@@ -678,15 +683,10 @@ class MessageProcessor:
             'appNavs': [app_nav]
         }
         async with aiohttp.ClientSession() as session:
-            fc_account_res = await voltage_client.fpeDecrypt(FC_ACCOUNT_ID, 'ASCII_ALPHANUM_PIN')
-            fc_token_res = await voltage_client.fpeDecrypt(FC_ACCOUNT_TOKEN, 'ASCII_ALPHANUM_PIN')
-            fc_account = fc_account_res.get('text',None)
-            fc_token = fc_token_res.get('text',None)
             
-            fc_auth = aiohttp.BasicAuth(fc_account, fc_token)
-            endpoint = f"{FC_ENDPOINT}/Accounts/{fc_account}/Calls/{fc_token}/AppNavs"
-
             try:
+                fc_auth = aiohttp.BasicAuth(CDR_ACCOUNT_ID, CDR_ACCOUNT_TOKEN)
+                endpoint = f"{CDR_ENDPOINT}/Accounts/{CDR_ACCOUNT_ID}/Calls/{CDR_ACCOUNT_TOKEN}/AppNavs"
                 async with session.post(endpoint, auth=fc_auth, data=payload, ssl=False) as response:
                     logger.info('[{}] - cdr submission: {}'.format(conversation_id, response.status))
             except aiohttp.ClientConnectorError as e:
@@ -705,7 +705,7 @@ class MessageProcessor:
                     'value:': 'disconnect'
                 }
                 logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
-                #asyncio.create_task(self.send_app_nav_async(sender_id, app_nav))
+                asyncio.create_task(self.send_app_nav_async(sender_id, app_nav))
                 APP_NAV.labels(message._metadata['template_name'], 'disconnect').inc()
 
             elif message._metadata and message._metadata.get('message_type', None) == 'SPOKEN':
@@ -715,7 +715,7 @@ class MessageProcessor:
                     'value:': 'NO_NTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
-                    #asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
+                    asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
                     APP_NAV.labels(message._metadata['template_name'], message._metadata['reporting_error_type']).inc()
                     
                 elif message.missed_intent and message.intent['confidence'] < message._metadata['nlu_threshold']:
@@ -724,7 +724,7 @@ class MessageProcessor:
                     'value:': 'NO_NTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
-                    #asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
+                    asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
                     APP_NAV.labels(message._metadata['template_name'], 'no_match').inc()
                     
                 elif message.intent['confidence'] > message._metadata['nlu_threshold']:
@@ -733,7 +733,7 @@ class MessageProcessor:
                     'value:': message.intent
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
-                    #asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
+                    asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
                     APP_NAV.labels(message._metadata['template_name'], 'match').inc()
                 else:
                     logger.debug("[{}] - APP NAV: Error logging app_nav: {}".format(sender_id, message))
