@@ -393,21 +393,6 @@ def create_app(
 
     app = Sanic(__name__)
     app.config.RESPONSE_TIMEOUT = 60 * 60
-    app.health_check_urls = []
-
-    if endpoints:
-        if endpoints.duckling:
-            app.health_check_urls.append(endpoints.duckling.url)
-
-        if endpoints.action:
-            action_server_url = endpoints.action.url.replace('/webhook', '')
-            app.health_check_urls.append(f'{action_server_url}/healthz/live')
-
-        if endpoints.idp:
-            app.health_check_urls.append(f'{endpoints.idp.url}/health')
-
-        if endpoints.upm:
-            app.health_check_urls.append(f'{endpoints.upm.url}/liveness')
 
     configure_cors(app, cors_origins)
 
@@ -495,35 +480,16 @@ def create_app(
     @app.get("/healthz/ready")
     async def ready(request: Request):
         """Check if the server is running and responds with the version."""
-        timeout = 30
-        services_status = [False for url in app.health_check_urls]
-        _broker = app.agent.tracker_store.event_broker
-
         try:
             if os.environ.get('READY_CHECK_OFF', None):
                 return response.json({"status": "ok"})
-
-            start = time.perf_counter()
-            results = await asyncio.gather(*[fetch(app.session, url, timeout) for url in app.health_check_urls])
-            duration = time.perf_counter() - start
-            OUTGOING_REQUEST_LATENCY_SEC.labels("total_healthcheck_duration", "NA", "GET").observe(duration)
-
-            for i in range(len(results)):
-                services_status[i] = results[i]
-
-            if _broker and not _broker.is_connected():
-                raise ErrorResponse(500, "ServerError", "Event broker is not available.")
-
+            if endpoints.tracker_store:
+                resp = await app.agent.tracker_store.is_healthy()
+                if not resp:
+                    logger.error({"event": "HEALTH_CHECK", "message": "Tracker store is unhealthy."})
+                    raise ErrorResponse(500, "ServerError", "Tracker store is unhealthy.")
             if not app.agent.is_ready():
                 raise ErrorResponse(500, "AgentError", "Agent is not ready yet.")
-            else:
-                for i in range(len(services_status)):
-                    if services_status[i] != 200:
-                        url = app.health_check_urls[i]
-                        raise ErrorResponse(500, "ServerReadiness", f"Failed to get a success response from {url}.")
-            return response.json({"status": "ok"})
-        except asyncio.CancelledError:
-            logger.warning({"event": "HEALTH_CHECK", "message": 'Readiness check task was cancelled.'})
             return response.json({"status": "ok"})
         except Exception as err:
             logger.error({"event": "HEALTH_CHECK", "message": f'Dialog Manager is not ready. {err}'}, exc_info=True)
@@ -661,9 +627,9 @@ def create_app(
                     if isinstance(event, UserUttered) and event.intent.get("name") == USER_INTENT_DISCONNECT and not tracker.conversation_ended():
                         tracker.update(event, app.agent.domain)
                         if tracker.from_voice_channel():
-                            outcome = 'Hangup'
+                            outcome = 'HANGUP'
                         else:
-                            outcome = 'Disconnected'
+                            outcome = 'DISCONNECTED'
                         val = {"name": "CONVERSATION_END", "message": outcome}
                         tracker.update(SlotSet("outcome", value=outcome, timestamp=event.timestamp + 1))
                         tracker.update(SlotSet("system_event", value=val, timestamp=event.timestamp + 2))
