@@ -1,8 +1,13 @@
 import pytest
+from typing import Callable
+from _pytest.pytester import RunResult
 
 
 @pytest.mark.repeat(3)
-def test_cli_start(run):
+def test_cli_start(run: Callable[..., RunResult]):
+    """
+    Startup of cli should not take longer than n seconds
+    """
     import time
 
     start = time.time()
@@ -11,10 +16,11 @@ def test_cli_start(run):
 
     duration = end - start
 
-    assert duration < 3  # startup of cli should not take longer than 3 seconds
+    # When run in parallel, it takes a little longer
+    assert duration <= 6
 
 
-def test_data_convert_help(run):
+def test_data_convert_help(run: Callable[..., RunResult]):
     output = run("--help")
 
     help_text = """usage: rasa [-h] [--version]
