@@ -260,6 +260,16 @@ async def test_convert_messge_to_digits_8(default_processor: MessageProcessor):
     assert logged_event.entities_redacted is not None
     assert logged_event.text_redacted == "my cc is 1284281111111111"
 
+async def test_convert_messge_to_digits_9(default_processor: MessageProcessor):
+    from rasa.core.trackers import DialogueStateTracker
+
+    message = UserMessage("for forward autopay auto pay won")
+    tracker = DialogueStateTracker("1", [])
+    await default_processor._handle_message_with_tracker(message, tracker)
+    logged_event = tracker.events[-1]
+    assert logged_event.entities_redacted is not None
+    assert logged_event.text_redacted == "four forward autopay auto pay one"
+
 async def test_convert_messge_to_digits_greet(default_processor: MessageProcessor):
     from rasa.core.trackers import DialogueStateTracker
 
